diff src/os_unix.c @ 7239:89c6f7c6704a v7.4.928

commit https://github.com/vim/vim/commit/5d8afebb5bf7fb1e8ce06062451dc6a1f9a53ac0 Author: Bram Moolenaar <Bram@vim.org> Date: Thu Nov 19 19:55:16 2015 +0100 patch 7.4.928 Problem: A clientserver message interrupts handling keys of a mapping. Solution: Have mch_inchar() send control back to WaitForChar when it is interrupted by server message. (James Kolb)
author Christian Brabandt <cb@256bit.org>
date Thu, 19 Nov 2015 20:00:05 +0100
parents fa95595fbc52
children c97735aaef9f
line wrap: on
line diff
--- a/src/os_unix.c
+++ b/src/os_unix.c
@@ -401,9 +401,15 @@ mch_inchar(buf, maxlen, wtime, tb_change
     {
 	while (WaitForChar(wtime) == 0)		/* no character available */
 	{
-	    if (!do_resize)	/* return if not interrupted by resize */
+	    if (do_resize)
+		handle_resize();
+#ifdef FEAT_CLIENTSERVER
+	    else if (!server_waiting())
+#else
+	    else
+#endif
+		/* return if not interrupted by resize or server */
 		return 0;
-	    handle_resize();
 #ifdef MESSAGE_QUEUE
 	    parse_queued_messages();
 #endif